@@ -14,17 +14,17 @@ embed.aov <- function(x, ina) {
   g <- max(ina)  ## how many groups are there
   ni <- as.vector(table(ina))
   x <- as.matrix(x)
-  x <- x/sqrt(rowSums(x^2))  ## makes sure x are unit vectors
-  p <- ncol(x)  ## dimensionality of the data
-  n <- nrow(x)  ## sample size of the data
+  x <- x / sqrt( Rfast::rowsums(x^2) )   ## makes sure x are unit vectors
+  p <- dim(x)[2]  ## dimensionality of the data
+  n <- dim(x)[1]  ## sample size of the data
 
   S <- rowsum(x, ina) / ni
-  Rbi <- sqrt( rowSums(S^2) ) ## the mean resultant length of each group
-  S <- as.vector( Rfast::colmeans(x) )
+  Rbi <- sqrt( Rfast::rowsums(S^2) ) ## the mean resultant length of each group
+  S <- Rfast::colmeans(x) 
   Rbar <- sqrt( sum(S^2) )  ## the mean resultant length based on all the data
 
-  Ft <- ((n - g) * (p - 1) * ( sum(ni * Rbi^2) - n * Rbar^2) )/( (g - 1) *
-                                                                   (p - 1) * (n - sum(ni * Rbi^2)) )
+  Ft <-  (n - g) * (p - 1) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( (g - 1) *
+    (p - 1) * ( n - sum(ni * Rbi^2) ) )
 
   pvalue <- pf(Ft, (g - 1) * (p - 1), (n - g) * (p - 1), lower.tail = FALSE)
   res <- c(Ft, pvalue)
