@@ -12,7 +12,7 @@ het.circaov <- function(u, ina, rads = FALSE) {
   n <- length(u)  ## sample size
   ina <- as.numeric(ina)
   g <- max(ina)  ## how many groups are there
-  ni <- as.vector(table(ina))
+  ni <- as.vector( table(ina) )
   ## if the data are in degrees we transform them into radians
 
   if ( rads == FALSE )  u <- u * pi/180
@@ -24,10 +24,10 @@ het.circaov <- function(u, ina, rads = FALSE) {
 
   mi <- atan(S/C) + pi * as.numeric(C<0)
   Ri <- sqrt(C^2 + S^2)  ## the resultant length of each group
-  for (i in 1:g) kappa[i] <- circ.summary( u[ina == i], rads = TRUE, plot = FALSE )$kappa
+  for (i in 1:g)  kappa[i] <- circ.summary( u[ina == i], rads = TRUE, plot = FALSE )$kappa
 
   ## kappa contains the estimated concentration parameters of each group
-  Rw <- sqrt( (sum(kappa * Ri * cos(mi)) )^2 + ( sum( kappa * Ri * sin(mi) ) )^2 )
+  Rw <- sqrt( sum( kappa * Ri * cos(mi) )^2 + sum( kappa * Ri * sin(mi) )^2 )
   Ta <- 2 * ( sum(kappa * Ri) - Rw )
   pvalue <- pchisq(Ta, g - 1, lower.tail = FALSE)
   res <- c(Ta, pvalue)
