@@ -15,31 +15,31 @@ knn.reg <- function(xnew, y, x, k = 5, res = "eucl", type = "euclidean", estim =
   ## harmonic mean of the closest observations
 
   y <- as.matrix(y)
-  d <- ncol(y)  ## dimensions of y
+  d <- dim(y)[2]  ## dimensions of y
   x <- as.matrix(x)
-  p <- ncol(x)  ## dimensions of x
-  n <- nrow(y)
+  p <- dim(x)[2]  ## dimensions of x
+  n <- dim(y)[1]
   xnew <- as.matrix(xnew)
   xnew <- matrix(xnew, ncol = p)
   nu <- nrow(xnew)
 
   if ( type == "spher" ) {
     ## calculates distance matrix for (hyper-)spherical data
-    x <- x / sqrt( rowSums(x^2) )  ## makes sure x are unit vectors
-    xnew <- xnew / sqrt( rowSums(xnew^2) )  ## makes sure x are unit vectors
+    x <- x / sqrt( Rfast::rowsums(x^2) )  ## makes sure x are unit vectors
+    xnew <- xnew / sqrt( Rfast::rowsums(xnew^2) )  ## makes sure x are unit vectors
 
     dis <- tcrossprod(xnew, x)
     dis[ dis >= 1 ] <- 1
     disa <- acos(dis)
 
   } else if ( type =="euclidean" || type == "manhattan" ) {
-    m <- as.vector( Rfast::colmeans(x) )
-    s <- as.vector( Rfast::colVars(x, std = TRUE) )
+    m <- Rfast::colmeans(x) 
+    s <- Rfast::colVars(x, std = TRUE) 
     x <- ( t(x) - m ) / s ## standardize the independent variables
     x <- t(x)
 
     if (p == 1) {
-      xnew <-as.vector(xnew)
+      xnew <- as.vector(xnew)
       xnew <- (xnew - m) / s
     } else if ( p > 1 ) {
       xnew <- ( t(xnew) - m ) / s  ## standardize the xnew values
@@ -61,7 +61,7 @@ knn.reg <- function(xnew, y, x, k = 5, res = "eucl", type = "euclidean", estim =
 
        for (i in 1:nu) {
          zz <- z - xnew[i, ]
-         disa[i, ] <- sqrt( colSums( zz^2 ) )
+         disa[i, ] <- sqrt( Rfast::colsums( zz^2 ) ) 
        }
 
     } else if (type == "manhattan") {
@@ -69,7 +69,7 @@ knn.reg <- function(xnew, y, x, k = 5, res = "eucl", type = "euclidean", estim =
 
       for (i in 1:nu) {
         a <- z - xnew[i, ]
-        disa[i, ] <- as.vector( Rfast::colsums( abs(a) ) )
+        disa[i, ] <- Rfast::colsums( abs(a) )
       }
     }
 
@@ -84,7 +84,7 @@ knn.reg <- function(xnew, y, x, k = 5, res = "eucl", type = "euclidean", estim =
       qan <- xa[order(xa[, 2]), ]
       a <- qan[1:k, 1]
       yb <- as.matrix( y[a, ] )
-      est[i, ] <- as.vector( Rfast::colmeans( yb ) )
+      est[i, ] <- Rfast::colmeans( yb )
     }
 
   } else if (estim == "harmonic") {
@@ -93,12 +93,12 @@ knn.reg <- function(xnew, y, x, k = 5, res = "eucl", type = "euclidean", estim =
       qan <- xa[order(xa[, 2]), ]
       a <- qan[1:k, 1]
       yb <- as.matrix( y[a, ] )
-      est[i, ] <- k / as.vector( Rfast::colsums( yb ) )
+      est[i, ] <- k / Rfast::colsums( yb ) 
     }
   }
 
   if (res == "spher") {
-    y <- y / sqrt( rowSums(y^2) )
+    y <- y / sqrt( Rfast::rowsums(y^2) ) 
   } else  y <- y
 
   if ( is.null(colnames(y)) ) {
