@@ -13,18 +13,18 @@ lr.aov <- function(x, ina) {
   ina <- as.numeric(ina)
   g <- max(ina)  ## how many groups are there
   x <- as.matrix(x)
-  x <- x/sqrt(rowSums(x^2))  ## makes sure x are unit vectors
-  p <- ncol(x)  ## dimensionality of the data
-  n <- nrow(x)  ## sample size of the data
+  x <- x / sqrt( Rfast::rowsums(x^2) )  ## makes sure x are unit vectors
+  p <- dim(x)[2]  ## dimensionality of the data
+  n <- dim(x)[1]  ## sample size of the data
 
   S <- rowsum(x, ina)
-  Ri <- sqrt( rowSums(S^2) )  ## the resultant length of each group
-  S <- colSums(x)
+  Ri <- sqrt( Rfast::rowsums(S^2) )  ## the resultant length of each group
+  S <- Rfast::colsums(x) 
   R <- sqrt( sum(S^2) )  ## the resultant length based on all the data
 
   ## Next we stimate the common concentration parameter kappa under H0 and H1
   Apk <- function(p, k) {
-    besselI(k, p/2, expon.scaled = T)/besselI(k, p/2 - 1, expon.scaled = T)
+    besselI(k, p/2, expon.scaled = TRUE) / besselI(k, p/2 - 1, expon.scaled = TRUE)
   }
 
   Rk <- R/n
@@ -58,12 +58,12 @@ lr.aov <- function(x, ina) {
 
   k1 <- k[j]  ## concentration parameter under H1
   apk0 <- (1 - p/2) * log(k0/2) + lgamma(p/2) +
-    log(besselI(k0, p/2 - 1, expon.scaled = T)) + k0
+    log( besselI( k0, p/2 - 1, expon.scaled = TRUE ) ) + k0
   apk1 <- (1 - p/2) * log(k1/2) + lgamma(p/2) +
-    log(besselI(k1, p/2 - 1, expon.scaled = T)) + k1
+    log( besselI( k1, p/2 - 1, expon.scaled = TRUE ) ) + k1
   w <- 2 * (k1 * sum(Ri) - k0 * R - n * apk1 + n * apk0)
 
-  pvalue <- 1 - pchisq(w, (g - 1) * (p - 1))
+  pvalue <- pchisq(w, (g - 1) * (p - 1), lower.tail = FALSE)
   res <- c(w, pvalue)
   names(res) <- c('w', 'p-value')
   res
