@@ -11,15 +11,14 @@
 mediandir_2 = function(x) {
   ## x is the directional data
   x = as.matrix(x)
-  x = x / sqrt( rowSums(x^2) )
-  n = nrow(x)  ;  p = ncol(x)
+  x = x / sqrt( Rfast::rowsums(x^2) )
 
    funa = function(pa) {
     pa = pa / sqrt( sum(pa^2) )
     mean( acos( x %*% pa ) )
    }
 
-  pa = as.vector( Rfast::colmeans(x) )
+  pa = Rfast::colMedians(x)
   bar = optim( pa, funa, control = list(maxit = 10000) )
   bar = optim( bar$par, funa, control = list(maxit = 10000) )
   bar = optim( bar$par, funa, control = list(maxit = 10000) )
